==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/ru/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Неподдерживаемый метод сжатия</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Инициализация сжатия завершена с ошибкой</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Сжатие XMPP потока</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Позволяет сжимать поток сообщений отправляемый и получаемый от сервера</translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Неправильный уровень сжатия</translation>
    </message>
    <message>
        <source>invalid or incomplete deflate data</source>
        <translation>неправильные или неполные данные для сжатия</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Не хватает памяти для Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Неверная версия Zlib!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Неверный ответ во время инициализации сжатия</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/ru/compress.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
<context>
    <name>CompressPlugin</name>
    <message>
        <source>Unsupported compression method</source>
        <translation>Неподдерживаемый метод сжатия</translation>
    </message>
    <message>
        <source>Compression setup failed</source>
        <translation>Инициализация сжатия завершена с ошибкой</translation>
    </message>
    <message>
        <source>Stream Compression</source>
        <translation>Сжатие XMPP потока</translation>
    </message>
    <message>
        <source>Allows to compress a stream of messages sent and received from the server</source>
        <translation>Позволяет сжимать поток сообщений отправляемый и получаемый от сервера</translation>
    </message>
    <message>
        <source>Enable data compression transferred between client and server</source>
        <translation>Включить сжатие данных передаваемых между клиентом и сервером</translation>
    </message>
</context>
<context>
    <name>Compression</name>
    <message>
        <source>Invalid compression level</source>
        <translation>Неправильный уровень сжатия</translation>
    </message>
    <message>
        <source>Out of memory for Zlib</source>
        <translation>Не хватает памяти для Zlib</translation>
    </message>
    <message>
        <source>Zlib version mismatch!</source>
        <translation>Неверная версия Zlib!</translation>
    </message>
    <message>
        <source>Wrong compression negotiation response</source>
        <translation>Неверный ответ во время инициализации сжатия</translation>
    </message>
    <message>
        <source>Invalid or incomplete deflate data</source>
        <translation>Неправильные или неполные данные для сжатия</translation>
    </message>
    <message>
        <source>Unknown Zlib error, %1</source>
        <translation>Неизвестная ошибка Zlib, %1</translation>
    </message>
</context>
</TS>
